Improve this doc

# Error: ngOptions:iexp
Invalid Expression

    Expected expression in form of '_select_ (as _label_)? for (_key_,)?_value_ in _collection_' but got '{0}'. Element: {1}

## Description

This error occurs when 'ngOptions' is passed an expression that isn't in an expected form.

Here's an example of correct syntax:

    <select ng-model="color" ng-options="c.name for c in colors">

For more information on valid expression syntax, see 'ngOptions' in select directive docs.